"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BullMonitor = void 0;
const data_sources_1 = require("./gql/data-sources");
const type_defs_1 = require("./gql/type-defs");
const resolvers_1 = require("./gql/resolvers");
const ui_1 = require("./ui");
class BullMonitor {
    constructor(config) {
        this._defaultConfig = {
            queues: [],
            baseUrl: '',
            gqlIntrospection: true,
            gqlPlayground: true,
        };
        this.gqlBasePath = '/graphql';
        this.config = Object.assign(Object.assign({}, this._defaultConfig), config);
        this.ui = new ui_1.UI();
    }
    createServer(Server) {
        this.server = new Server({
            typeDefs: type_defs_1.typeDefs,
            // @ts-ignore
            resolvers: resolvers_1.resolvers,
            playground: this.config.gqlPlayground,
            introspection: this.config.gqlIntrospection,
            dataSources: () => ({
                bull: new data_sources_1.BullDataSource(this.config.queues),
            }),
        });
    }
    startServer() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.server.start();
        });
    }
    renderUi() {
        return this.ui.render();
    }
    get baseUrl() {
        return this.config.baseUrl;
    }
    get uiEndpoint() {
        return this.baseUrl || '/';
    }
    get gqlEndpoint() {
        const base = this.baseUrl;
        if (!base) {
            return this.gqlBasePath;
        }
        else if (base.endsWith('/')) {
            return base.slice(0, -1) + this.gqlBasePath;
        }
        return base + this.gqlBasePath;
    }
}
exports.BullMonitor = BullMonitor;
//# sourceMappingURL=index.js.map